"""
Settings for Webflow Client

An example of an options class could be:

.. code-block:: python

    class my_settings(Default):
	local = False
	workflow = [{'name':'sml_to_pl'}, {'name': 'pl_to_xml'}]
	models = ['lintul', 'miscanmod']

This would run the processes 'sml_to_pl', the 'pl_to_xml' (in that order) on model versions
'lintul_v1' then 'miscanmod_v1'. Processes would be run remotely (i.e. on webflow server).
"""

class Default(object):
    """
    Default options. Note similarity with options in webflow_client.py.
    This is necessary because if --settings is provided, options gets
    overridden by this class (or subclass).

    each element of a worfklow is equivalent to a step in webflow
    therefore they can (but don't have to ) define a in/out_file_pre_ext
    to deal with .gen files.
    Their order is important too.
    """
    local    = True
    path     = '/home/robert/mercurial/plasmo_models'
    url      = 'http://webflow/'
    workflow = []
    models   = []
    process  = None
    test     = None

class local_test(Default):
    local    = True
    workflow = [{'name':'sml_to_pl'}, {'name': 'pl_to_xml'}]
    #workflow = [{'name':'sml_to_pl'}, {'name': 'pl_to_xml'}, {'name': 'validate_pl', 'in_file_pre_ext': '.gen'}]
    models   = ['lintul', 'lynx_hares']

class remote_test(Default):
    local    = False
    workflow = [{'name':'sml_to_pl'}, {'name': 'pl_to_xml'}]
    models   = ['lintul', '3pg']

class complete(Default):
    pass

class current(Default):
    pass
